Learn R Programming

XLConnect (version 1.3.0)

xlcDump: Dumping data sets to Excel files

Description

Dumps data sets to Excel files by writing each object to a separate worksheet.

Usage

xlcDump(list, ..., file = "dump.xlsx", pos = -1, overwrite = FALSE)

Arguments

Value

Named logical vector specifying if objects have been dumped or not. An object may not be dumped because there was an issue with the coercion to a data.frame or the object already existed (and overwrite = FALSE) in the workbook.

Details

Each object is written to a separate worksheet named by the name of the object. Objects are written using the writeWorksheet method - as such any object will be coerced to data.frame.

See Also

xlcRestore, writeNamedRegion, writeWorksheet, writeNamedRegionToFile, writeWorksheetToFile, xlcEdit

Examples

Run this code
if (FALSE) {
require(datasets)
xlcDump(c("airquality", "CO2", "iris", "PlantGrowth", "swiss"),
        file = "myDump.xlsx", pos = "package:datasets")
xlcRestore(file = "myDump.xlsx", overwrite = TRUE)
# clean up
file.remove("myDump.xlsx")
}

Run the code above in your browser using DataLab